@@ -165,11 +165,7 @@ DEFAULT_CONFIG: ConfigBase = {
     "destination": "./_site",
     "include": [".htaccess"],
     "exclude": [],
-    "exclude_patterns": [
-        r"^[\.#].*",
-        r".*~$",
-        r".*\.s[uvw][a-z]$",  # *.swp files, etc.
-    ],
+    "exclude_patterns": [r"^[\.#].*", r".*~$", r".*\.sw[op]$"],
     "full_build_patterns": [
         r"_layouts",
         r"_includes",
@@ -747,7 +743,7 @@ def new_site(path: str) -> None:
 
 
 def obraz(argv: list[str]) -> None:
-    opts = docopt(__doc__ or "", argv=argv, version="0.9")
+    opts = docopt(__doc__ or "", argv=argv, version="0.9.5")
     global _quiet
     _quiet = opts["--quiet"]
 
